@@ -42,7 +42,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     // set default style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
@@ -65,6 +65,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                          i18n("A convergent weather application for Plasma"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2022 Plasma Development Team"));
+    aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/kweather/-/issues?sort=created_date&state=opened");
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("espidev@gmail.com"), QStringLiteral("https://espi.dev"));
     KAboutData::setApplicationData(aboutData);
@@ -89,7 +90,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<LocationQueryModel>("kweather", 1, 0, "LocationQueryModel");
     qmlRegisterType<WeatherLocation>("kweather", 1, 0, "WeatherLocation");
 
-    qRegisterMetaType<KWeatherCore::Sunrise>();
     qRegisterMetaType<KWeatherCore::HourlyWeatherForecast>();
     qRegisterMetaType<KWeatherCore::DailyWeatherForecast>();
     qRegisterMetaType<QList<WeatherLocation *>>();
